---
title: <span class="badge object-type-scalar"></span> ExaFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> ExaFlopsPerSecond

Computation: EFLOP/s

## Definition

```python
# Computation: EFLOP/s
ExaFlopsPerSecond: typing.Literal["eflops"] = "eflops"
```
